Crate lincoln_compiled

Crate lincoln_compiled 

Structs

Context
A Context is a container of values. Ideally it should not have more than 20 elements but this is not a hard limit.
GroupRef
A GroupRef refers to a group of CodeRef, used for Entry::Call to implement conditional control flow.
Permutation
Program

Enums

BuildError
CodeRef
CodeRef is a type refer to a single executable entry. This can be either a entry of a program, an external entry point defined within/without the program, or indicate the end of execution.
CodeRefError
EvalError
EvalFn
ExternEntry
An ExternEntry refer to a function provided by the external function.
ValueAccessError
ValueFn

Traits

Access
A trait for field access
AsPermutation
Value

Functions

native_closure
unwrap
wrap