Structs
- Context
- A Context is a container of values. Ideally it should not have more than 20 elements but this is not a hard limit.
- Group
Ref - A
GroupRefrefers to a group ofCodeRef, used forEntry::Callto implement conditional control flow. - Permutation
- Program
Enums
- Build
Error - CodeRef
- CodeRef is a type refer to a single executable entry. This can be either a entry of a program, an external entry point defined within/without the program, or indicate the end of execution.
- Code
RefError - Eval
Error - EvalFn
- Extern
Entry - An
ExternEntryrefer to a function provided by the external function. - Value
Access Error - ValueFn
Traits
- Access
- A trait for field access
- AsPermutation
- Value